@@ -11,6 +11,10 @@ def groupSections(topTrends, script, pageStart):
 
     newScript = categorizeSections(topTrends, script, pageStart)
     newScript = combineCategories(newScript, pageStart)
+
+    file1 = open('./test.json', 'w+')
+    json.dump(newScript, file1, indent=4, ensure_ascii=False)
+
     newScript = divideParentheticals(newScript)
     return newScript
 
@@ -92,7 +96,7 @@ def combineCategories(newScript, pageStart):
                 elif sectionSameTypeAsPrevious and scene["type"] == "ACTION":
                     # if part of same paragraph, concat text
                     if (scene["content"][0]["y"] - finalSections[-1]["content"][-1]["scene"][-1]["content"][-1]["y"] <= 16):
-                        finalSections[-1]["content"][-1]["scene"][-1]["content"][-1]["text"] += scene["content"][0]["text"]
+                        finalSections[-1]["content"][-1]["scene"][-1]["content"][-1]["text"] += " " + scene["content"][0]["text"]
                         finalSections[-1]["content"][-1]["scene"][-1]["content"][-1]["y"] = scene["content"][0]["y"]
                     # else, just append entire text
                     else:
